@@ -1,7 +1,7 @@
 package Data::Password::zxcvbn::Match::UserInput;
 use Moo;
 extends 'Data::Password::zxcvbn::Match::Dictionary';
-our $VERSION = '1.0.0'; # VERSION
+our $VERSION = '1.0.1'; # VERSION
 # ABSTRACT: match class for words that match other user-supplied information
 
 
@@ -31,7 +31,7 @@ sub make {
             # all words have rank 1, they're the first thing that a
             # cracker would try
             $user_dicts{$field} = {
-                map { $_ => 1 } @words,
+                map { lc($_) => 1 } @words, ## no critic(ProhibitUselessTopic)
             };
         }
     }
@@ -78,7 +78,7 @@ Data::Password::zxcvbn::Match::UserInput - match class for words that match othe
 
 =head1 VERSION
 
-version 1.0.0
+version 1.0.1
 
 =head1 DESCRIPTION
 
